==> react-modal-basic-1.19.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import { createPortal } from 'react-dom';
import IconX from '@s-ui/react-icons/lib/X';
import cx from 'classnames';
var CLASS_MODAL_OPEN = 'is-modal-open';

var ModalBasic =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(ModalBasic, _Component);

  function ModalBasic() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.contentDOMEl = React.createRef();
    _this.wrapperDOMEl = React.createRef();
    _this.state = {
      isClientReady: false,
      open: _this.props.open
    };

    _this._preventScrollIfNeeded = function (e) {
      if (_this.noScroll) e.preventDefault();
    };

    _this._avoidOverscroll = function () {
      var current = _this.contentDOMEl.current;
      var clientHeight = current.clientHeight,
          offsetHeight = current.offsetHeight,
          scrollTop = current.scrollTop,
          scrollHeight = current.scrollHeight;
      var currentScroll = scrollTop + offsetHeight; // check if the content has to scroll in order to prevent the default
      // behaviour of the touchmove in case we don't need the scroll
      // that fixes the weird overscroll on ios and android

      _this.noScroll = scrollHeight <= clientHeight;

      if (scrollTop === 0) {
        current.scrollTop = 1;
      } else if (currentScroll >= scrollHeight) {
        current.scrollTop = scrollTop - 1;
      }
    };

    _this._closeModal = function () {
      _this._toggleWindowScroll(false);

      _this.setState({
        open: false
      });

      _this.props.onClose();
    };

    _this._handleCloseClick = function () {
      _this._closeModal();
    };

    _this._handleOutsideClick = function (event) {
      if (_this.props.closeOnOutsideClick && event.target === _this.wrapperDOMEl.current) {
        _this._closeModal();
      }
    };

    _this._renderHeader = function () {
      var _this$props = _this.props,
          header = _this$props.header,
          textClose = _this$props.textClose,
          textCloseHidden = _this$props.textCloseHidden,
          IconClose = _this$props.iconClose;
      return React.createElement("div", {
        className: "sui-ModalBasic-header",
        onTouchMove: function onTouchMove(e) {
          return e.preventDefault();
        }
      }, header, React.createElement("button", {
        className: "sui-ModalBasic-close",
        onClick: _this._handleCloseClick,
        type: "button"
      }, React.createElement(IconClose, {
        svgClass: "sui-ModalBasic-closeIcon"
      }), textCloseHidden ? React.createElement("span", {
        className: "sui-ModalBasic-closeTextHidden"
      }, textClose) : textClose));
    };

    return _this;
  }

  var _proto = ModalBasic.prototype;

  _proto._getContainer = function _getContainer() {
    var portalContainerId = this.props.portalContainerId;
    var containerDOMEl = document.getElementById(portalContainerId); // if container is not created, create it and attach to the body

    if (!containerDOMEl) {
      containerDOMEl = document.createElement('div');
      containerDOMEl.id = portalContainerId;
      document.body.appendChild(containerDOMEl);
    }

    return containerDOMEl;
  };

  _proto._toggleWindowScroll = function _toggleWindowScroll(disableScroll) {
    var classList = window.document.body.classList;
    disableScroll ? classList.add(CLASS_MODAL_OPEN) : classList.remove(CLASS_MODAL_OPEN);
  };

  _proto._renderModal = function _renderModal() {
    var _this$props2 = this.props,
        className = _this$props2.className,
        content = _this$props2.content,
        header = _this$props2.header,
        footer = _this$props2.footer;
    var wrapperClassName = cx('sui-ModalBasic', className, {
      'is-open': this.state.open,
      'sui-ModalBasic--verticallyCentered': this.props.centerVertically
    });
    var dialogClassName = cx('sui-ModalBasic-dialog', {
      'sui-ModalBasic-dialog--full': this.props.fitWindow
    });
    return React.createElement("div", {
      className: wrapperClassName,
      ref: this.wrapperDOMEl,
      onClick: this._handleOutsideClick
    }, React.createElement("div", {
      className: dialogClassName
    }, header && this._renderHeader(), React.createElement("div", {
      className: "sui-ModalBasic-content",
      onTouchStart: this._avoidOverscroll,
      onTouchMove: this._preventScrollIfNeeded,
      ref: this.contentDOMEl
    }, content), footer && React.createElement("div", {
      className: "sui-ModalBasic-footer"
    }, footer)));
  };

  _proto.componentDidMount = function componentDidMount() {
    // portals should work only in client, so, if usePortal is enabled
    // we will use a flag in order to render the component only in client
    var usePortal = this.props.usePortal;

    if (usePortal) {
      this.setState({
        isClientReady: true
      });
    }
  };

  _proto.UNSAFE_componentWillReceiveProps = function UNSAFE_componentWillReceiveProps(_ref) {
    var open = _ref.open,
        disableWindowScroll = _ref.disableWindowScroll;

    // eslint-disable-line
    if (disableWindowScroll) {
      this._toggleWindowScroll(open);
    }

    if (open !== this.state.open) {
      this.setState({
        open: open
      });
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    this._toggleWindowScroll(false);
  };

  _proto.render = function render() {
    var usePortal = this.props.usePortal;
    var isClientReady = this.state.isClientReady;

    var modalElement = this._renderModal();

    if (usePortal) {
      // check if we're in the client using the flag isClientReady
      // as portals are only usable in client
      return isClientReady ? createPortal(modalElement, this._getContainer()) : null;
    }

    return modalElement;
  };

  return ModalBasic;
}(Component);

ModalBasic.defaultProps = {
  centerVertically: false,
  closeOnOutsideClick: false,
  disableWindowScroll: true,
  fitWindow: false,
  iconClose: IconX,
  onClose: function onClose() {},
  open: false,
  portalContainerId: 'modal-react-portal',
  textClose: 'Close',
  textCloseHidden: true,
  usePortal: false
};
ModalBasic.displayName = 'ModalBasic';
export default ModalBasic;

==> react-modal-basic-1.20.0.tgz: package/lib/index.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
import { createRef, Component } from 'react';
import { createPortal } from 'react-dom';
import IconX from '@s-ui/react-icons/lib/X';
import cx from 'classnames';
var CLASS_MODAL_OPEN = 'is-modal-open';

var ModalBasic = /*#__PURE__*/function (_Component) {
  _inheritsLoose(ModalBasic, _Component);

  function ModalBasic() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.contentDOMEl = /*#__PURE__*/createRef();
    _this.wrapperDOMEl = /*#__PURE__*/createRef();
    _this.state = {
      isClientReady: false,
      open: _this.props.open
    };

    _this._preventScrollIfNeeded = function (e) {
      if (_this.noScroll) e.preventDefault();
    };

    _this._avoidOverscroll = function () {
      var current = _this.contentDOMEl.current;
      var clientHeight = current.clientHeight,
          offsetHeight = current.offsetHeight,
          scrollTop = current.scrollTop,
          scrollHeight = current.scrollHeight;
      var currentScroll = scrollTop + offsetHeight; // check if the content has to scroll in order to prevent the default
      // behaviour of the touchmove in case we don't need the scroll
      // that fixes the weird overscroll on ios and android

      _this.noScroll = scrollHeight <= clientHeight;

      if (scrollTop === 0) {
        current.scrollTop = 1;
      } else if (currentScroll >= scrollHeight) {
        current.scrollTop = scrollTop - 1;
      }
    };

    _this._closeModal = function () {
      _this._toggleWindowScroll(false);

      _this.setState({
        open: false
      });

      _this.props.onClose();
    };

    _this._handleCloseClick = function () {
      _this._closeModal();
    };

    _this._handleOutsideClick = function (event) {
      if (_this.props.closeOnOutsideClick && event.target === _this.wrapperDOMEl.current) {
        _this._closeModal();
      }
    };

    _this._renderHeader = function () {
      var _this$props = _this.props,
          header = _this$props.header,
          textClose = _this$props.textClose,
          textCloseHidden = _this$props.textCloseHidden,
          IconClose = _this$props.iconClose;
      return /*#__PURE__*/_jsxs("div", {
        className: "sui-ModalBasic-header",
        onTouchMove: function onTouchMove(e) {
          return e.preventDefault();
        },
        children: [header, /*#__PURE__*/_jsxs("button", {
          className: "sui-ModalBasic-close",
          onClick: _this._handleCloseClick,
          type: "button",
          children: [/*#__PURE__*/_jsx(IconClose, {
            svgClass: "sui-ModalBasic-closeIcon"
          }), textCloseHidden ? /*#__PURE__*/_jsx("span", {
            className: "sui-ModalBasic-closeTextHidden",
            children: textClose
          }) : textClose]
        })]
      });
    };

    return _this;
  }

  var _proto = ModalBasic.prototype;

  _proto._getContainer = function _getContainer() {
    var portalContainerId = this.props.portalContainerId;
    var containerDOMEl = document.getElementById(portalContainerId); // if container is not created, create it and attach to the body

    if (!containerDOMEl) {
      containerDOMEl = document.createElement('div');
      containerDOMEl.id = portalContainerId;
      document.body.appendChild(containerDOMEl);
    }

    return containerDOMEl;
  };

  _proto._toggleWindowScroll = function _toggleWindowScroll(disableScroll) {
    var classList = window.document.body.classList;
    disableScroll ? classList.add(CLASS_MODAL_OPEN) : classList.remove(CLASS_MODAL_OPEN);
  };

  _proto._renderModal = function _renderModal() {
    var _this$props2 = this.props,
        className = _this$props2.className,
        content = _this$props2.content,
        header = _this$props2.header,
        footer = _this$props2.footer;
    var wrapperClassName = cx('sui-ModalBasic', className, {
      'is-open': this.state.open,
      'sui-ModalBasic--verticallyCentered': this.props.centerVertically
    });
    var dialogClassName = cx('sui-ModalBasic-dialog', {
      'sui-ModalBasic-dialog--full': this.props.fitWindow
    });
    return /*#__PURE__*/_jsx("div", {
      className: wrapperClassName,
      ref: this.wrapperDOMEl,
      onClick: this._handleOutsideClick,
      children: /*#__PURE__*/_jsxs("div", {
        className: dialogClassName,
        children: [header && this._renderHeader(), /*#__PURE__*/_jsx("div", {
          className: "sui-ModalBasic-content",
          onTouchStart: this._avoidOverscroll,
          onTouchMove: this._preventScrollIfNeeded,
          ref: this.contentDOMEl,
          children: content
        }), footer && /*#__PURE__*/_jsx("div", {
          className: "sui-ModalBasic-footer",
          children: footer
        })]
      })
    });
  };

  _proto.componentDidMount = function componentDidMount() {
    // portals should work only in client, so, if usePortal is enabled
    // we will use a flag in order to render the component only in client
    var usePortal = this.props.usePortal;

    if (usePortal) {
      this.setState({
        isClientReady: true
      });
    }
  };

  _proto.UNSAFE_componentWillReceiveProps = function UNSAFE_componentWillReceiveProps(_ref) {
    var open = _ref.open,
        disableWindowScroll = _ref.disableWindowScroll;

    // eslint-disable-line
    if (disableWindowScroll) {
      this._toggleWindowScroll(open);
    }

    if (open !== this.state.open) {
      this.setState({
        open: open
      });
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    this._toggleWindowScroll(false);
  };

  _proto.render = function render() {
    var usePortal = this.props.usePortal;
    var isClientReady = this.state.isClientReady;

    var modalElement = this._renderModal();

    if (usePortal) {
      // check if we're in the client using the flag isClientReady
      // as portals are only usable in client
      return isClientReady ? /*#__PURE__*/createPortal(modalElement, this._getContainer()) : null;
    }

    return modalElement;
  };

  return ModalBasic;
}(Component);

ModalBasic.defaultProps = {
  centerVertically: false,
  closeOnOutsideClick: false,
  disableWindowScroll: true,
  fitWindow: false,
  iconClose: IconX,
  onClose: function onClose() {},
  open: false,
  portalContainerId: 'modal-react-portal',
  textClose: 'Close',
  textCloseHidden: true,
  usePortal: false
};
ModalBasic.displayName = 'ModalBasic';
export default ModalBasic;
